streetscape
===========

collect panoramic street views in a city

Set up
======

1. Clone repository
~~~~~~~~~~~~~~~~~~~

::

    git clone git@github.com:yonghah/streetscape.git
    cd streetscape

2. Install package
~~~~~~~~~~~~~~~~~~

::

    pip install .

3. Set GSV\_API\_KEY
~~~~~~~~~~~~~~~~~~~~

::

    export GSV_API_KEY=YOUR_GOOGLE_STREET_VIEW_API_KEY
